@@ -14,14 +14,8 @@ import types
 import numbers
 import collections
 import ctypes
-import os
-import sys
-import warnings
-import platform
-from . import exceptions
 from .api import library, libc, MagickPixelPacket
-from .resource import (increment_refcount, decrement_refcount, Resource,
-                       DestroyedResourceError)
+from .resource import Resource, DestroyedResourceError
 from .color import Color
 
 
@@ -49,8 +43,12 @@ __all__ = 'FILTER_TYPES', 'Image', 'Iterator', 'ClosedImageError'
 #:
 #: .. seealso::
 #:
-#:    `ImageMagick Resize Filters
-#:    <http://www.dylanbeattie.net/magick/filters/result.html>`_
+#:    `ImageMagick Resize Filters`__
+#:       Demonstrates the results of resampling three images using the various
+#:       resize filters and blur settings available in ImageMagick,
+#:       and the file size of the resulting thumbnail images.
+#:
+#:    __ http://www.dylanbeattie.net/magick/filters/result.html
 FILTER_TYPES = ('undefined', 'point', 'box', 'triangle', 'hermite', 'hanning',
                 'hamming', 'blackman', 'gaussian', 'quadratic', 'cubic',
                 'catrom', 'mitchell', 'lanczos', 'bessel', 'sinc')
@@ -241,7 +239,10 @@ class Image(Resource):
                       y.start is None and y.stop is None):
                     return self.clone()
                 cloned = self.clone()
-                cloned.crop(x.start, y.start, x.stop, y.stop)
+                try:
+                    cloned.crop(x.start, y.start, x.stop, y.stop)
+                except ValueError as e:
+                    raise IndexError(str(e))
                 return cloned
             else:
                 return self[idx[0]]
@@ -287,6 +288,15 @@ class Image(Resource):
 
         It may raise :exc:`ValueError` when the format is unsupported.
 
+        .. seealso::
+
+           `ImageMagick Image Formats`__
+              ImageMagick uses an ASCII string known as *magick* (e.g. ``GIF``)
+              to identify file formats, algorithms acting as formats,
+              built-in patterns, and embedded profile types.
+
+           __ http://www.imagemagick.org/script/formats.php
+
         """
         fmt = library.MagickGetImageFormat(self.wand)
         if fmt:
@@ -396,7 +406,7 @@ class Image(Resource):
             elif not isinstance(n, numbers.Integral):
                 raise TypeError('expected integer, not ' + repr(n))
             elif n > m:
-                raise IndexError(repr(n) + ' > ' + repr(m))
+                raise ValueError(repr(n) + ' > ' + repr(m))
             return m + n if n < 0 else n
         left = abs_(left, self.width, 0)
         top = abs_(top, self.height, 0)
@@ -427,8 +437,9 @@ class Image(Resource):
         :param filter: a filter type to use for resizing. choose one in
                        :const:`FILTER_TYPES`. default is ``'triangle'``
         :type filter: :class:`basestring`, :class:`numbers.Integral`
-        :param blur: the blur factor where > 1 is blurry, < 1 is sharp
-        :type blur: :class:`numbers.Rational`
+        :param blur: the blur factor where > 1 is blurry, < 1 is sharp.
+                     default is 1
+        :type blur: :class:`numbers.Real`
 
         """
         if width is None:
@@ -447,8 +458,8 @@ class Image(Resource):
         elif height < 1:
             raise ValueError('height must be a natural number, not ' +
                              repr(height))
-        elif not isinstance(blur, numbers.Rational):
-            raise TypeError('blur must be numbers.Rational, not ' + repr(blur))
+        elif not isinstance(blur, numbers.Real):
+            raise TypeError('blur must be numbers.Real , not ' + repr(blur))
         elif not isinstance(filter, (basestring, numbers.Integral)):
             raise TypeError('filter must be one string defined in wand.image.'
                             'FILTER_TYPES or an integer, not ' + repr(filter))
@@ -457,13 +468,39 @@ class Image(Resource):
                 filter = FILTER_TYPES.index(filter)
             except IndexError:
                 raise ValueError(repr(filter) + ' is an invalid filter type; '
-                                 'choose on in ' + repr(FILTET_TYPES))
+                                 'choose on in ' + repr(FILTER_TYPES))
         elif (isinstance(filter, numbers.Integral) and
               not (0 <= filter < len(FILTER_TYPES))):
             raise ValueError(repr(filter) + ' is an invalid filter type')
         blur = ctypes.c_double(float(blur))
         library.MagickResizeImage(self.wand, width, height, filter, blur)
 
+    def rotate(self, degree, background=None):
+        """Rotates the image. It takes a ``background`` color for ``degree``
+        that isn't a multiple of 45.
+
+        :param degree: a degree to rotate. multiples of 360 affect nothing
+        :type degree: :class:`numbers.Real`
+        :param background: an optional background color.
+                           default is transparent
+        :type background: :class:`wand.color.Color`
+
+        """
+        if background is None:
+            background = Color('transparent')
+        elif not isinstance(background, Color):
+            raise TypeError('background must be a wand.color.Color instance, '
+                            'not ' + repr(background))
+        if not isinstance(degree, numbers.Real):
+            raise TypeError('degree must be a numbers.Real value, not ' +
+                            repr(degree))
+        with background:
+            result = library.MagickRotateImage(self.wand,
+                                               background.resource,
+                                               degree)
+        if not result:
+            self.raise_exception()
+
     def save(self, file=None, filename=None):
         """Saves the image into the ``file`` or ``filename``. It takes
         only one argument at a time.
